@@ -1,5 +1,6 @@
 """Object-specific python package to run automated tasks in the Chase Lab."""
-
+import warnings
+warnings.filterwarnings("ignore")
 from .ffsync import ffsync
 from .ffconcat import ffconcat
 from .lazytrim import lazytrim
